
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/basic/materielInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "物料信息",
      name: "materielInfo",
      url: "/MaterielInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      warehouseId: "",
      materielCode: "",
      materielName: "",
      materielDes: "",
      isMixBatch: "",
      isMixMateriel: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "仓库",
          field: "warehouseId",
          type: "select",
          dataKey: "warehouses",
          data: [],
          required: true,
        },
        {
          title: "物料编号",
          required: true,
          field: "materielCode",
          type: "string",
        },
      ],
      [
         {
          title: "物料名称",
          required: true,
          field: "materielName",
          type: "string",
        },
        {
          title: "物料规格",
          required: true,
          field: "materielSpec",
          type: "string",
        },
      ],
      [
       {
          title: "物料基本分类",
          required: true,
          field: "materielType",
          type: "select",
          dataKey:"materielTypeEnum",
          data:[]
          
        },
        {
        field: "materielSourceType",
        title: "物料属性分类",
        required: true,
        type: "select",
        dataKey:"materielSourceTypeEnum",
        data:[]
      },  
      ],
      [
        {
          title: "基本单位",
          required: true,
          field: "materielUnit",
          type: "string",
        },
        {
          title: "物料状态",
          required: true,
          field: "materielState",
          type: "select",
          dataKey:"enableEnum",
          data:[]
        },
        
      ],
      [
        {
          title: "库存组织",
          required: true,
          field: "materielInvOrgId",
          type: "string",
        },
        {
          title: "是否需要质检",
          required: true,
          field: "isCheck",
          type: "select",
          dataKey:"yesno",
          data:[]
        },
      ]
      
    ]);
    const searchFormFields = ref({
      materielCode: "",
      materielName: "",
    });
    const searchFormOptions = ref([
      [
        { title: "物料编号", field: "materielCode", type: "like" },
        { title: "物料名称", field: "materielName", type: "like" },
        {title: "所属仓库", field:"warehouseId",type:"select",dataKey:"warehouses",data:[]}
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "仓库",
        type: "string",
        width: 100,
        align: "left",
        bind: { key: "warehouses", data: [] },
      },
      {
        field: "materielCode",
        title: "物料编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "materielName",
        title: "物料名称",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "materielSpec",
        title: "物料规格",
        type: "string",
        width: 240,
        align: "left",
      },
      {
        field: "materielSourceType",
        title: "物料属性分类",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "materielSourceTypeEnum", data: [] },
      },
      {
        field: "materielType",
        title: "物料基本分类",
        type: "string",
        width: 120,
        align: "left",
    
      },
      {
        field: "materielUnit",
        title: "基本单位",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "materielSize",
        title: "物料尺寸",
        type: "float",
        width: 180,
        align: "left",
      },
      {
        field: "materielLength",
        title: "物料长度",
        type: "float",
        width: 120,
        align: "left",
      },
      {
        field: "materielThickness",
        title: "物料厚度",
        type: "float",
        width: 120,
        align: "left",
      },
      {
        field: "materielState",
        title: "物料状态",
        type: "select",
        width: 100,
        bind:{key:"",data: [{key:'Enable',value:'启用'},{key:'Disable',value:'禁用'}] },
        align: "left",
      },
      {
        field: "materielInvOrgId",
        title: "库存组织",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "isCheck",
        title: "是否需要质检",
        type: "int",
        bind:{key:"",data: [{key:'False',value:'否'},{key:'True',value:'是'}] },
        width: 100,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
        hidden:true
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
        hidden:true
      },
      
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    